import harkpython.harkbasenode as harkbasenode
import numpy
import pylab


class HarkNode (harkbasenode.HarkBaseNode):
    def __init__(self):
        self.outputNames = ("output",)
        self.outputTypes = ("prim_int",)
        pylab.ion()
        pylab.hold(False)

        # plot width in samples
        self.width = 51
        self.zrange = [-1, 1]
        
        self.buffer = None

    def calculate(self):
        # Dummy output
        self.outputValues["output"] = 0

        # Check if spectrum is valid or not
        data = numpy.array(self.spec)
        if data.sum() == 0:
            return

        # Update buffer
        if self.buffer is None:
            self.buffer = data[:, numpy.newaxis]
        else:
            self.buffer = numpy.c_[self.buffer, data][:, -self.width:]

        #  update vmax/vmin 
        self.zrange[0] = max(self.zrange[0], self.buffer.max())
        self.zrange[1] = min(self.zrange[1], self.buffer.min())

        # plot spectrum
        pylab.clf()
        pylab.imshow(numpy.flipud(self.buffer), aspect="auto",
                     interpolation="nearest",
                     vmax=self.zrange[0],
                     vmin=self.zrange[1])
        pylab.colorbar()
        pylab.draw()

